==> plasma-framework-5.110.0.zip: plasma-framework-5.110.0/src/desktoptheme/oxygen/metadata.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "kde-artists@kde.org",
                "Name": "The Oxygen Project",
                "Name[az]": "Oxygen layihəsi",
                "Name[be]": "Праект \"Oxygen\"",
                "Name[bg]": "Проектът Oxygen",
                "Name[ca@valencia]": "The Oxygen Project",
                "Name[ca]": "The Oxygen Project",
                "Name[cs]": "Projekt Oxygen",
                "Name[en_GB]": "The Oxygen Project",
                "Name[eo]": "La Oksigeno-Projekto",
                "Name[es]": "El proyecto Oxígeno",
                "Name[eu]": "«Oxygen» proiektua",
                "Name[fi]": "Oxygen-projekti",
                "Name[fr]": "Le projet « Oxygen »",
                "Name[gl]": "O proxecto Osíxeno",
                "Name[ia]": "Le projecto Oxigen",
                "Name[id]": "The Oxygen Project",
                "Name[it]": "Il progetto Oxygen",
                "Name[ka]": "The Oxygen Project",
                "Name[ko]": "The Oxygen Project",
                "Name[nl]": "Het project Oxygen",
                "Name[nn]": "Oxygen-prosjektet",
                "Name[pl]": "Projekt Tlenu",
                "Name[pt]": "O Projecto Oxygen",
                "Name[pt_BR]": "O projeto Oxygen",
                "Name[ru]": "Проект Oxygen",
                "Name[sl]": "Projekt kisik",
                "Name[sv]": "Oxygen-projektet",
                "Name[tr]": "Oksijen Projesi",
                "Name[uk]": "Проєкт Oxygen",
                "Name[vi]": "Dự án Oxygen",
                "Name[x-test]": "xxThe Oxygen Projectxx",
                "Name[zh_CN]": "Oxygen 项目"
            }
        ],
        "Category": "",
        "Description": "Theme done in the Oxygen style",
        "Description[az]": "Mövzu Oxygen stilində hazırlanıb",
        "Description[be]": "Тэма створаная ў стылі Oxygen",
        "Description[bg]": "Тема в стил Oxygen",
        "Description[ca@valencia]": "Tema fet en l'estil Oxygen",
        "Description[ca]": "Tema fet en l'estil Oxygen",
        "Description[cs]": "Motiv ve stylu Oxygen",
        "Description[en_GB]": "Theme done in the Oxygen style",
        "Description[eo]": "Etoso farita en la stilo de Oksigeno",
        "Description[es]": "Tema realizado al estilo de Oxígeno",
        "Description[eu]": "Oxygen-en estilora egindako gaia",
        "Description[fi]": "Oxygen-tyylillä tehty teema",
        "Description[fr]": "Thème réalisé selon un thème « Oxygen »",
        "Description[gl]": "Tema feito no estilo Oxygen.",
        "Description[ia]": "Thema facite in le stilo de Oxygen",
        "Description[id]": "Tema dilakukan dalam gaya Oksigen",
        "Description[it]": "Tema realizzato nello stile di Oxygen",
        "Description[ka]": "Oxygen-ის სტილში შესრულებული თემა",
        "Description[ko]": "Oxygen 스타일의 기본 테마",
        "Description[nl]": "Thema in Oxygen-stijl",
        "Description[nn]": "Tema laga i Oxygen-stilen",
        "Description[pl]": "Wystrój wzorowany na stylu Tlen",
        "Description[pt]": "Tema criado no estilo do Oxygen",
        "Description[pt_BR]": "Tema feito no estilo Oxygen",
        "Description[ru]": "Тема, выполненная в стиле Oxygen",
        "Description[sl]": "Teme izdelana v slogu Kisika",
        "Description[sv]": "Tema skapat med Oxygen-stilen",
        "Description[tr]": "Oksijen tarzında yapılmış tema",
        "Description[uk]": "Тема в стилі Oxygen",
        "Description[vi]": "Chủ đề được tạo với kiểu cách Oxygen",
        "Description[x-test]": "xxTheme done in the Oxygen stylexx",
        "Description[zh_CN]": "Oxygen 轻氧风格的主题",
        "EnabledByDefault": true,
        "Id": "oxygen",
        "License": "GPL",
        "Name": "Oxygen",
        "Name[az]": "Oxygen ayarları",
        "Name[be]": "Oxygen",
        "Name[bg]": "Oxygen",
        "Name[ca@valencia]": "Oxygen",
        "Name[ca]": "Oxygen",
        "Name[cs]": "Oxygen",
        "Name[de]": "Oxygen",
        "Name[en_GB]": "Oxygen",
        "Name[eo]": "Oksigeno",
        "Name[es]": "Oxígeno",
        "Name[eu]": "Oxigenoa",
        "Name[fi]": "Oxygen",
        "Name[fr]": "Oxygen",
        "Name[gl]": "Osíxeno",
        "Name[ia]": "Oxygen",
        "Name[id]": "Oxygen",
        "Name[it]": "Oxygen",
        "Name[ka]": "ჟანგბადი",
        "Name[ko]": "Oxygen",
        "Name[nl]": "Oxygen",
        "Name[nn]": "Oxygen",
        "Name[pl]": "Tlen",
        "Name[pt]": "Oxygen",
        "Name[pt_BR]": "Oxygen",
        "Name[ro]": "Oxygen",
        "Name[ru]": "Oxygen",
        "Name[sl]": "Kisik",
        "Name[sv]": "Oxygen",
        "Name[tr]": "Oksijen",
        "Name[uk]": "Oxygen",
        "Name[vi]": "Oxygen",
        "Name[x-test]": "xxOxygenxx",
        "Name[zh_CN]": "Oxygen 轻氧",
        "Version": "@KF_VERSION@",
        "Website": "https://plasma.kde.org"
    },
    "X-Plasma-API": "5.0"
}

==> plasma-framework-5.113.0.zip: plasma-framework-5.113.0/src/desktoptheme/oxygen/metadata.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "kde-artists@kde.org",
                "Name": "The Oxygen Project",
                "Name[az]": "Oxygen layihəsi",
                "Name[be]": "Праект \"Oxygen\"",
                "Name[bg]": "Проектът Oxygen",
                "Name[ca@valencia]": "El projecte Oxygen",
                "Name[ca]": "The Oxygen Project",
                "Name[cs]": "Projekt Oxygen",
                "Name[en_GB]": "The Oxygen Project",
                "Name[eo]": "La Oksigeno-Projekto",
                "Name[es]": "El proyecto Oxígeno",
                "Name[eu]": "«Oxygen» proiektua",
                "Name[fi]": "Oxygen-projekti",
                "Name[fr]": "Le projet « Oxygen »",
                "Name[gl]": "O proxecto Osíxeno",
                "Name[ia]": "Le projecto Oxigen",
                "Name[id]": "The Oxygen Project",
                "Name[it]": "Il progetto Oxygen",
                "Name[ka]": "The Oxygen Project",
                "Name[ko]": "The Oxygen Project",
                "Name[nl]": "Het project Oxygen",
                "Name[nn]": "Oxygen-prosjektet",
                "Name[pl]": "Projekt Tlenu",
                "Name[pt]": "O Projecto Oxygen",
                "Name[pt_BR]": "O projeto Oxygen",
                "Name[ru]": "Проект Oxygen",
                "Name[sl]": "Projekt kisik",
                "Name[sv]": "Oxygen-projektet",
                "Name[tr]": "Oksijen Projesi",
                "Name[uk]": "Проєкт Oxygen",
                "Name[vi]": "Dự án Oxygen",
                "Name[x-test]": "xxThe Oxygen Projectxx",
                "Name[zh_CN]": "Oxygen 项目"
            }
        ],
        "Category": "",
        "Description": "Theme done in the Oxygen style",
        "Description[az]": "Mövzu Oxygen stilində hazırlanıb",
        "Description[be]": "Тэма створаная ў стылі Oxygen",
        "Description[bg]": "Тема в стил Oxygen",
        "Description[ca@valencia]": "Tema fet en l'estil Oxygen",
        "Description[ca]": "Tema fet en l'estil Oxygen",
        "Description[cs]": "Motiv ve stylu Oxygen",
        "Description[en_GB]": "Theme done in the Oxygen style",
        "Description[eo]": "Etoso farita en la stilo de Oksigeno",
        "Description[es]": "Tema realizado al estilo de Oxígeno",
        "Description[eu]": "Oxygen-en estilora egindako gaia",
        "Description[fi]": "Oxygen-tyylillä tehty teema",
        "Description[fr]": "Thème réalisé selon un thème « Oxygen »",
        "Description[gl]": "Tema feito no estilo Oxygen.",
        "Description[ia]": "Thema facite in le stilo de Oxygen",
        "Description[id]": "Tema dilakukan dalam gaya Oksigen",
        "Description[it]": "Tema realizzato nello stile di Oxygen",
        "Description[ka]": "Oxygen-ის სტილში შესრულებული თემა",
        "Description[ko]": "Oxygen 스타일의 기본 테마",
        "Description[nl]": "Thema in Oxygen-stijl",
        "Description[nn]": "Tema laga i Oxygen-stilen",
        "Description[pl]": "Wystrój wzorowany na stylu Tlen",
        "Description[pt]": "Tema criado no estilo do Oxygen",
        "Description[pt_BR]": "Tema feito no estilo Oxygen",
        "Description[ru]": "Тема, выполненная в стиле Oxygen",
        "Description[sl]": "Teme izdelana v slogu Kisika",
        "Description[sv]": "Tema skapat med Oxygen-stilen",
        "Description[tr]": "Oksijen tarzında yapılmış tema",
        "Description[uk]": "Тема в стилі Oxygen",
        "Description[vi]": "Chủ đề được tạo với kiểu cách Oxygen",
        "Description[x-test]": "xxTheme done in the Oxygen stylexx",
        "Description[zh_CN]": "Oxygen 轻氧风格的主题",
        "EnabledByDefault": true,
        "Id": "oxygen",
        "License": "GPL",
        "Name": "Oxygen",
        "Name[az]": "Oxygen ayarları",
        "Name[be]": "Oxygen",
        "Name[bg]": "Oxygen",
        "Name[ca@valencia]": "Oxygen",
        "Name[ca]": "Oxygen",
        "Name[cs]": "Oxygen",
        "Name[de]": "Oxygen",
        "Name[en_GB]": "Oxygen",
        "Name[eo]": "Oksigeno",
        "Name[es]": "Oxígeno",
        "Name[eu]": "Oxigenoa",
        "Name[fi]": "Oxygen",
        "Name[fr]": "Oxygen",
        "Name[gl]": "Osíxeno",
        "Name[ia]": "Oxygen",
        "Name[id]": "Oxygen",
        "Name[it]": "Oxygen",
        "Name[ka]": "ჟანგბადი",
        "Name[ko]": "Oxygen",
        "Name[nl]": "Oxygen",
        "Name[nn]": "Oxygen",
        "Name[pl]": "Tlen",
        "Name[pt]": "Oxygen",
        "Name[pt_BR]": "Oxygen",
        "Name[ro]": "Oxygen",
        "Name[ru]": "Oxygen",
        "Name[sl]": "Kisik",
        "Name[sv]": "Oxygen",
        "Name[tr]": "Oksijen",
        "Name[uk]": "Oxygen",
        "Name[vi]": "Oxygen",
        "Name[x-test]": "xxOxygenxx",
        "Name[zh_CN]": "Oxygen 轻氧",
        "Version": "@KF_VERSION@",
        "Website": "https://plasma.kde.org"
    },
    "X-Plasma-API": "5.0"
}
